Crate conch_shell

Crate conch_shell 

Core library for the conch shell.

This crate is consumed by the conch binary (main.rs) and exists as its own library target so its public API can be documented and published on docs.rs.

Functions

run
Runs conch.